@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2017-01-13'; # DATE
-our $VERSION = '0.74'; # VERSION
+our $DATE = '2017-01-14'; # DATE
+our $VERSION = '0.75'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -183,16 +183,15 @@ sub _process_script {
     my $modified;
     for my $s (@{ $res->[3]{'func.sections'} }) {
         next unless $s->{content};
-        $self->add_text_to_section(
+        $modified++ if $self->add_text_to_section(
             $document, $s->{content}, $s->{name},
             {
                 (ignore => $s->{ignore}) x !!$s->{ignore},
             });
-        $modified++;
     }
 
     if ($modified) {
-        $self->log(["added POD sections from Rinci metadata for script '%s'", $filename]);
+        $self->log(["added POD sections from Rinci metadata for script '%s'", $input->{filename}]);
     }
 }
 
@@ -245,7 +244,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.74 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2017-01-13.
+This document describes version 0.75 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2017-01-14.
 
 =head1 SYNOPSIS
 
